.. contents::

============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given. 

Types of Contributions
----------------------
You can contribute in many ways:

Bug Reports
~~~~~~~~~~~

Report bugs at https://github.com/nbargnesi/nbargnesi/lazarus/issues.

Before reporting a bug, read these:

* http://www.chiark.greenend.org.uk/~sgtatham/bugs.html
* http://www.catb.org/~esr/faqs/smart-questions.html

Bug Fixes
~~~~~~~~~

Look through the GitHub issues for `anything tagged with "bug"`_.

.. _anything tagged with "bug": https://github.com/nbargnesi/lazarus/issues?labels=bug&page=1&state=open

Enhancements
~~~~~~~~~~~~

Look through the GitHub issues for `anything tagged with "enhancement"`_.

.. _anything tagged with "enhancement": https://github.com/nbargnesi/lazarus/issues?labels=enhancement&page=1&state=open

Documentation
~~~~~~~~~~~~~

Lazarus could always use more documentation, whether as part of the official
nbargnesi/lazarus docs, in docstrings, or even on the web in blog posts,
articles, and such.

Feedback
~~~~~~~~

The best way to send feedback is to file an issue at
https://github.com/nbargnesi/lazarus/issues.

